##  Description
IT components are powerful for getting crucial insights for obsolescence risk management, operating costs, and managing other risks such as provider/location/outage management. In addition, you need IT components to drive, e.g., your organization’s cloud strategy.
IT components are building blocks of applications that run, maintain, and change applications. They don’t directly support business capabilities. They are offered by providers and grouped into tech categories for standardization.
Overview of all relations to/from IT component:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275372ec7a441014bbf4f2b834d26e6a_LowRes.png)
